@@ -1,4 +1,4 @@
-__all__ = ['ISBNToolsHTTPError', 'ISBNToolsURLError',
+__all__ = ('ISBNToolsHTTPError', 'ISBNToolsURLError',
            'DataNotFoundAtServiceError',
            'ServiceIsDownError', 'DataWrongShapeError',
            'NotValidMetadataError', 'Metadata', 'stdmeta',
@@ -7,7 +7,7 @@ __all__ = ['ISBNToolsHTTPError', 'ISBNToolsURLError',
            'NoDataForSelectorError', 'ServiceIsDownError',
            'DataWrongShapeError', 'NotValidMetadataError',
            'RecordMappingError', 'NoAPIKeyError'
-           ]
+           )
 
 
 from .webservice import WEBService
@@ -17,5 +17,5 @@ from .exceptions import (ISBNToolsHTTPError, ISBNToolsURLError,
                          NoDataForSelectorError, ServiceIsDownError,
                          DataWrongShapeError, NotValidMetadataError,
                          RecordMappingError, NoAPIKeyError)
-from .data import Metadata, stdmeta
+from ._data import Metadata, stdmeta
 from . import vias
